==> estateplat-common-1.2.3-20180506.025257-76-sources.jar: cn/gtmap/estateplat/model/commodityHouse/contract/FcjyXjspfBaMmhtGhsjbg.java <==
package cn.gtmap.estateplat.model.commodityHouse.contract;

import javax.persistence.Id;
import javax.persistence.Table;
import java.util.Date;


/*
 * @author <a href="mailto:zhangguangguang@gtmap.cn">zhangguangguang</a>
 * @version 1.0, 2018/04/20
 * @description    规划设计变更历史表
 */
@Table(name = "fcjy_xjspf_ba_mmht_ghsjbg")
public class FcjyXjspfBaMmhtGhsjbg {
    @Id
    private String bglsid;//主键
    private String htlsid;//合同历史表id
    private String bgid;//规划设计变更表主键
    private String htid;//合同ID
    private Integer ghbgjflx;//规划变更给付利息
    private Double ghbgwyj;//规划变更违约金
    private String ghbgsfyd;//规划变更双方约定
    private String bgtm3;//变更条目3
    private String bgtm4;//变更条目4
    private String bgtm5;//变更条目5
    private String sjbgjflx;//设计变更给付利息
    private Double sjbgwyj;//设计变更违约金
    private String sjbgsfyd;//设计变更双方约定
    private Date lssj;//历史时间
    private Integer lscs;//历史次数

    public String getBglsid() {
        return bglsid;
    }

    public void setBglsid(String bglsid) {
        this.bglsid = bglsid;
    }

    public String getHtlsid() { return htlsid; }

    public void setHtlsid(String htlsid) { this.htlsid = htlsid; }

    public String getBgid() {
        return bgid;
    }

    public void setBgid(String bgid) {
        this.bgid = bgid;
    }

    public String getHtid() {
        return htid;
    }

    public void setHtid(String htid) {
        this.htid = htid;
    }

    public Integer getGhbgjflx() {
        return ghbgjflx;
    }

    public void setGhbgjflx(Integer ghbgjflx) {
        this.ghbgjflx = ghbgjflx;
    }

    public Double getGhbgwyj() {
        return ghbgwyj;
    }

    public void setGhbgwyj(Double ghbgwyj) {
        this.ghbgwyj = ghbgwyj;
    }

    public String getGhbgsfyd() {
        return ghbgsfyd;
    }

    public void setGhbgsfyd(String ghbgsfyd) {
        this.ghbgsfyd = ghbgsfyd;
    }

    public String getBgtm3() {
        return bgtm3;
    }

    public void setBgtm3(String bgtm3) {
        this.bgtm3 = bgtm3;
    }

    public String getBgtm4() {
        return bgtm4;
    }

    public void setBgtm4(String bgtm4) {
        this.bgtm4 = bgtm4;
    }

    public String getBgtm5() {
        return bgtm5;
    }

    public void setBgtm5(String bgtm5) {
        this.bgtm5 = bgtm5;
    }

    public String getSjbgjflx() {
        return sjbgjflx;
    }

    public void setSjbgjflx(String sjbgjflx) {
        this.sjbgjflx = sjbgjflx;
    }

    public Double getSjbgwyj() {
        return sjbgwyj;
    }

    public void setSjbgwyj(Double sjbgwyj) {
        this.sjbgwyj = sjbgwyj;
    }

    public String getSjbgsfyd() {
        return sjbgsfyd;
    }

    public void setSjbgsfyd(String sjbgsfyd) {
        this.sjbgsfyd = sjbgsfyd;
    }

    public Date getLssj() { return lssj;}

    public void setLssj(Date lssj) { this.lssj = lssj;}

    public Integer getLscs() { return lscs; }

    public void setLscs(Integer lscs) { this.lscs = lscs; }
}

==> estateplat-common-1.2.3-20180612.081212-112-sources.jar: cn/gtmap/estateplat/model/commodityHouse/contract/FcjyXjspfBaMmhtGhsjbg.java <==
package cn.gtmap.estateplat.model.commodityHouse.contract;

import javax.persistence.Id;
import javax.persistence.Table;
import java.io.Serializable;
import java.util.Date;


/*
 * @author <a href="mailto:zhangguangguang@gtmap.cn">zhangguangguang</a>
 * @version 1.0, 2018/04/20
 * @description    规划设计变更历史表
 */
@Table(name = "fcjy_xjspf_ba_mmht_ghsjbg")
public class FcjyXjspfBaMmhtGhsjbg implements Serializable {
    @Id
    private String bglsid;//主键
    private String htlsid;//合同历史表id
    private String bgid;//规划设计变更表主键
    private String htid;//合同ID
    private Integer ghbgjflx;//规划变更给付利息
    private Double ghbgwyj;//规划变更违约金
    private String ghbgsfyd;//规划变更双方约定
    private String bgtm3;//变更条目3
    private String bgtm4;//变更条目4
    private String bgtm5;//变更条目5
    private String sjbgjflx;//设计变更给付利息
    private Double sjbgwyj;//设计变更违约金
    private String sjbgsfyd;//设计变更双方约定
    private Date lssj;//历史时间
    private Integer lscs;//历史次数

    public String getBglsid() {
        return bglsid;
    }

    public void setBglsid(String bglsid) {
        this.bglsid = bglsid;
    }

    public String getHtlsid() { return htlsid; }

    public void setHtlsid(String htlsid) { this.htlsid = htlsid; }

    public String getBgid() {
        return bgid;
    }

    public void setBgid(String bgid) {
        this.bgid = bgid;
    }

    public String getHtid() {
        return htid;
    }

    public void setHtid(String htid) {
        this.htid = htid;
    }

    public Integer getGhbgjflx() {
        return ghbgjflx;
    }

    public void setGhbgjflx(Integer ghbgjflx) {
        this.ghbgjflx = ghbgjflx;
    }

    public Double getGhbgwyj() {
        return ghbgwyj;
    }

    public void setGhbgwyj(Double ghbgwyj) {
        this.ghbgwyj = ghbgwyj;
    }

    public String getGhbgsfyd() {
        return ghbgsfyd;
    }

    public void setGhbgsfyd(String ghbgsfyd) {
        this.ghbgsfyd = ghbgsfyd;
    }

    public String getBgtm3() {
        return bgtm3;
    }

    public void setBgtm3(String bgtm3) {
        this.bgtm3 = bgtm3;
    }

    public String getBgtm4() {
        return bgtm4;
    }

    public void setBgtm4(String bgtm4) {
        this.bgtm4 = bgtm4;
    }

    public String getBgtm5() {
        return bgtm5;
    }

    public void setBgtm5(String bgtm5) {
        this.bgtm5 = bgtm5;
    }

    public String getSjbgjflx() {
        return sjbgjflx;
    }

    public void setSjbgjflx(String sjbgjflx) {
        this.sjbgjflx = sjbgjflx;
    }

    public Double getSjbgwyj() {
        return sjbgwyj;
    }

    public void setSjbgwyj(Double sjbgwyj) {
        this.sjbgwyj = sjbgwyj;
    }

    public String getSjbgsfyd() {
        return sjbgsfyd;
    }

    public void setSjbgsfyd(String sjbgsfyd) {
        this.sjbgsfyd = sjbgsfyd;
    }

    public Date getLssj() { return lssj;}

    public void setLssj(Date lssj) { this.lssj = lssj;}

    public Integer getLscs() { return lscs; }

    public void setLscs(Integer lscs) { this.lscs = lscs; }
}
